@@ -1,7 +1,7 @@
 ## no critic (ProhibitStringyEval ProhibitSubroutinePrototypes RequireLocalizedPunctuationVars)
 package Test::Expander;
 
-our $VERSION = '1.0.3';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
+our $VERSION = '1.0.4';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
 
 use v5.14;
 use warnings
@@ -108,11 +108,26 @@ sub import {
   $METHOD_REF = '-target' ~~ %options ? $CLASS->can($METHOD) : undef;
   $METHOD     = undef unless($METHOD_REF);
 
-  readonly_on($CLASS)      if $CLASS;
-  readonly_on($METHOD)     if $METHOD;
-  readonly_on($METHOD_REF) if $METHOD_REF;
-  readonly_on($TEMP_DIR)   if $TEMP_DIR;
-  readonly_on($TEMP_FILE)  if $TEMP_FILE;
+  if ($CLASS) {
+    readonly_on($CLASS);
+    note(q(Set $CLASS to '),      $CLASS,      q('));
+  }
+  if ($METHOD) {
+    readonly_on($METHOD);
+    note(q(Set $METHOD to '),     $METHOD,     q('));
+  }
+  if ($METHOD_REF) {
+    readonly_on($METHOD_REF);
+    note(q(Set $METHOD_REF to '), $METHOD_REF, q('));
+  }
+  if ($TEMP_DIR) {
+    readonly_on($TEMP_DIR);
+    note(q(Set $TEMP_DIR to '),   $TEMP_DIR,   q('));
+  }
+  if ($TEMP_FILE) {
+    readonly_on($TEMP_FILE);
+    note(q(Set $TEMP_FILE to '),  $TEMP_FILE,  q('));
+  }
 
   Importer->import_into($class, scalar(caller), ());
 
@@ -201,6 +216,7 @@ sub _readEnvFile {
     next unless $line =~ /^ (?<name> \w+) \s* = \s* (?<value> \S .*)/x;
     $env{$+{name}} = eval($+{value});
     die(sprintf($INVALID_ENV_ENTRY, $index, $envFile, $line, $@)) if $@;
+    note(q(Set environment variable '), $+{name}, q(' to '), $env{$+{name}}, q(' from file '), $envFile, q('));
   }
 
   return \%env;
@@ -221,7 +237,7 @@ sub _setEnv {
   if (path($envFile)->is_file) {
     $envFound                   = $TRUE unless $envFound;
     my $methodEnv               = _readEnvFile($envFile);
-    @$newEnv{keys(%$methodEnv)} = values(%$methodEnv)
+    @$newEnv{keys(%$methodEnv)} = values(%$methodEnv);
   }
 
   %ENV = %$newEnv if $envFound;
